==> apache-sis-1.4-src.zip: apache-sis-1.4-src/endorsed/src/org.apache.sis.referencing/main/org/apache/sis/xml/bind/referencing/CS_RangeMeaning.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.sis.xml.bind.referencing;

import org.opengis.referencing.cs.RangeMeaning;
import org.apache.sis.xml.bind.gml.CodeListAdapter;

import static org.apache.sis.util.internal.Constants.EPSG;


/**
 * JAXB adapter for (un)marshalling of GeoAPI code list.
 *
 * @author  Martin Desruisseaux (Geomatys)
 */
public final class CS_RangeMeaning extends CodeListAdapter<RangeMeaning> {
    /**
     * Empty constructor for JAXB only.
     */
    public CS_RangeMeaning() {
    }

    /**
     * {@inheritDoc}
     *
     * @return {@code RangeMeaning.class}
     */
    @Override
    protected Class<RangeMeaning> getCodeListClass() {
        return RangeMeaning.class;
    }

    /**
     * Sets the default code space to {@code "EPSG"}.
     *
     * @return {@code "EPSG"}.
     */
    @Override
    protected String getCodeSpace() {
        return EPSG;
    }
}

==> apache-sis-1.5-src.zip: apache-sis-1.5-src/endorsed/src/org.apache.sis.referencing/main/org/apache/sis/xml/bind/referencing/CS_RangeMeaning.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.sis.xml.bind.referencing;

import org.opengis.referencing.cs.RangeMeaning;
import org.apache.sis.xml.bind.gml.CodeListAdapter;
import static org.apache.sis.util.internal.shared.Constants.EPSG;


/**
 * JAXB adapter for (un)marshalling of GeoAPI code list.
 *
 * @author  Martin Desruisseaux (Geomatys)
 */
public final class CS_RangeMeaning extends CodeListAdapter<RangeMeaning> {
    /**
     * Empty constructor for JAXB only.
     */
    public CS_RangeMeaning() {
    }

    /**
     * {@inheritDoc}
     *
     * @return {@code RangeMeaning.class}
     */
    @Override
    protected Class<RangeMeaning> getCodeListClass() {
        return RangeMeaning.class;
    }

    /**
     * Sets the default code space to {@code "EPSG"}.
     *
     * @return {@code "EPSG"}.
     */
    @Override
    protected String getCodeSpace() {
        return EPSG;
    }
}
